==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.server/src/com/openexchange/groupware/attach/util/GetSwitch.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.attach.util;

import com.openexchange.groupware.attach.AttachmentField;
import com.openexchange.groupware.attach.AttachmentMetadata;

public class GetSwitch implements AttachmentField.AttachmentSwitch {

	private final AttachmentMetadata attachment;

	public GetSwitch(final AttachmentMetadata attachment) {
		this.attachment = attachment;
	}

	@Override
    public Object createdBy() {
		return attachment.getCreatedBy();
	}

	@Override
    public Object id() {
		return attachment.getId();
	}

	@Override
    public Object moduleId() {
		return attachment.getModuleId();
	}

	@Override
    public Object attachedId() {
		return attachment.getAttachedId();
	}

	@Override
    public Object fileSize() {
		return attachment.getFilesize();
	}

	@Override
    public Object fileMIMEType() {
		return attachment.getFileMIMEType();
	}

	@Override
    public Object creationDate() {
		return attachment.getCreationDate();
	}

	@Override
    public Object folderId() {
		return attachment.getFolderId();
	}

	@Override
    public Object fileName(){
		return attachment.getFilename();
	}

	@Override
    public Object rtfFlag(){
		return attachment.getRtfFlag();
	}

	@Override
    public Object comment() {
		return attachment.getComment();
	}

	@Override
    public Object fileId() {
		return attachment.getFileId();
	}

}

==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.server/src/com/openexchange/groupware/attach/util/GetSwitch.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.attach.util;

import static com.openexchange.java.Autoboxing.I;
import static com.openexchange.java.Autoboxing.L;
import com.openexchange.groupware.attach.AttachmentField;
import com.openexchange.groupware.attach.AttachmentMetadata;

public class GetSwitch implements AttachmentField.AttachmentSwitch {

	private final AttachmentMetadata attachment;

	public GetSwitch(final AttachmentMetadata attachment) {
		this.attachment = attachment;
	}

	@Override
    public Object createdBy() {
		return I(attachment.getCreatedBy());
	}

	@Override
    public Object id() {
		return I(attachment.getId());
	}

	@Override
    public Object moduleId() {
		return I(attachment.getModuleId());
	}

	@Override
    public Object attachedId() {
		return I(attachment.getAttachedId());
	}

	@Override
    public Object fileSize() {
		return L(attachment.getFilesize());
	}

	@Override
    public Object fileMIMEType() {
		return attachment.getFileMIMEType();
	}

	@Override
    public Object creationDate() {
		return attachment.getCreationDate();
	}

	@Override
    public Object folderId() {
		return I(attachment.getFolderId());
	}

	@Override
    public Object fileName(){
		return attachment.getFilename();
	}

	@Override
    public Object rtfFlag(){
		return attachment.getRtfFlag() ? Boolean.TRUE : Boolean.FALSE;
	}

	@Override
    public Object comment() {
		return attachment.getComment();
	}

	@Override
    public Object fileId() {
		return attachment.getFileId();
	}

	@Override
	public Object checksum() {
	    return attachment.getChecksum();
	}

}
